@@ -14,7 +14,7 @@ use Digest::SHA qw(hmac_sha256 hmac_sha256_hex);
 use MIME::Base64::URLSafe qw(urlsafe_b64decode);
 use Scalar::Util qw(blessed);
 
-our $VERSION = '1.25';
+our $VERSION = '1.30';
 
 sub new {
     my $class = shift;
@@ -451,7 +451,7 @@ sub request {
 
     my $content = q{};
     if ($method eq 'POST') {
-        if ($param_ref->{source} || $param_ref->{file}) {
+        if ($param_ref->{source} || $param_ref->{file} || $param_ref->{upload_phase} ) {
             # post image or video file
 
             # https://developers.facebook.com/docs/reference/api/video/
@@ -576,7 +576,7 @@ sub prep_param {
         $param_ref->{permissions} = ref $perms ? join q{,}, @$perms : $perms;
     }
 
-    # Source and file parameter contains file path.
+    # Source, file and video_file_chunk parameter contains file path.
     # It must be an array ref to work with HTTP::Request::Common.
     if (my $path = $param_ref->{source}) {
         $param_ref->{source} = ref $path ? $path : [$path];
@@ -584,6 +584,9 @@ sub prep_param {
     if (my $path = $param_ref->{file}) {
         $param_ref->{file} = ref $path ? $path : [$path];
     }
+    if (my $path = $param_ref->{video_file_chunk}) {
+        $param_ref->{video_file_chunk} = ref $path ? $path : [$path];
+    }
 
     # use Field Expansion
     if (my $field_ref = $param_ref->{fields}) {
@@ -683,7 +686,7 @@ Facebook::OpenGraph - Simple way to handle Facebook's Graph API.
 
 =head1 VERSION
 
-This is Facebook::OpenGraph version 1.25
+This is Facebook::OpenGraph version 1.30
 
 =head1 SYNOPSIS
 
